![icon](https://raw.githubusercontent.com/GaelHF/pymakergame/refs/heads/main/pymakergame/icon.png)
# PyMakerGame
Python Library That Makes Pygame Easy

## About
- Released: 12/20/2024
- Author: [@GaelHF](https://github.com/GaelHF)

## Current Version
0.1: First Version (Nothing)